cumulusci.core.source package
=============================

.. automodule:: cumulusci.core.source
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

cumulusci.core.source.github module
-----------------------------------

.. automodule:: cumulusci.core.source.github
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.core.source.local\_folder module
------------------------------------------

.. automodule:: cumulusci.core.source.local_folder
   :members:
   :undoc-members:
   :show-inheritance:

